#
# spec file for package socket_wrapper
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


############################# NOTE ##################################
#
# This is a special library. You are not able to link this library.
# Do NOT create library package or a devel package!
#
############################# NOTE ##################################

Name:           socket_wrapper
Version:        1.2.3
Release:        lp151.3.3.1
Summary:        A library passing all socket communications trough Unix sockets
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Url:            https://cwrap.org/
#
Source0:        https://ftp.samba.org/pub/cwrap/%{name}-%{version}.tar.gz
Source1:        https://ftp.samba.org/pub/cwrap/%{name}-%{version}.tar.gz.asc
Source2:        socket_wrapper.keyring
Source3:        %{name}-rpmlintrc
#
BuildRequires:  cmake
BuildRequires:  libcmocka-devel
BuildRequires:  pkg-config
#
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

Recommends:     cmake
Recommends:     pkgconf

%description
socket_wrapper aims to help client/server software development teams willing to
gain full functional test coverage. It makes it possible to run several instances
of the full software stack on the same machine and perform locally functional
testing of complex network configurations.

To use it set the following environment variables:

LD_PRELOAD=libsocket_wrapper.so
SOCKET_WRAPPER_DIR=/path/to/swrap_dir

%prep
%autosetup

%build
%cmake \
  -DUNIT_TESTING=ON

make %{?_smp_mflags} VERBOSE=1

%install
%cmake_install

%check
%ctest

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS README.md ChangeLog
%license LICENSE
%{_libdir}/libsocket_wrapper.so.*
%{_mandir}/man1/socket_wrapper.1*
%{_libdir}/libsocket_wrapper.so
%dir %{_libdir}/cmake/socket_wrapper
%{_libdir}/cmake/socket_wrapper/socket_wrapper-config-version.cmake
%{_libdir}/cmake/socket_wrapper/socket_wrapper-config.cmake
%{_libdir}/pkgconfig/socket_wrapper.pc

%changelog
* Mon Nov 25 2019 Samuel Cabrero <scabrero@suse.de>
- Update changelog to reference bsc#1157684.
* Thu Oct 31 2019 Andreas Schneider <asn@cryptomilk.org>
- Some spec file cleanups
* Wed Aug 21 2019 Andreas Schneider <asn@cryptomilk.org>
- Change Requires to Recommends for cmake and pkgconf
* Thu Mar 21 2019 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.2.3
  * Fixed missing NULL check for socket_wrapper_dir()
  * Fixes building in Samba source tree
* Thu Mar 21 2019 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.2.2
  * Added environment variable to disable deep binding
  * Fixed installation of socket_wrapper
  * Fixed several small bugs
* Wed Nov 14 2018 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.2.1
  * Removed error message to fix applications doing stupid things
* Tue Nov 13 2018 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.2.0
  * Added threading support
  * Moved to modern cmake
  * Several smaller bugfixes
* Mon Dec  4 2017 asn@cryptomilk.org
- Update to version 1.1.9
  * Fixed thread - signal deadlock issue
* Fri Oct 13 2017 asn@cryptomilk.org
- Update to version 1.1.8
  * Added support for openat()
  * Added support for open64() and fopen64()
  * Always enabled logging support
  * Increased maximum for wrapped interfaces to 64
  * Improved fd duplication code
  * Fixed strict-aliasing issues
  * Fixed some use after free issues
  * Fixed issues on ppc64le
* Tue May 31 2016 asn@cryptomilk.org
- Update to version 1.1.7
  * Added support for accept4()
  * Added support for OpenBSD
  * Fixed sendto() with UDP and a connected socket
  * Fixed AF_RAWLINK sockets
* Mon Mar 21 2016 asn@cryptomilk.org
- Update to version 1.1.6
  * Added a wrapper for write()
  * Added support for automatic binding of ephemeral ports
  * Fixed recvmsg() with UDP
  * Fixed AF_NETLINK sockets
* Sun Feb 14 2016 jengelh@inai.de
- Editorial fixes to the description
* Thu Oct 15 2015 asn@cryptomilk.org
- Update to version 1.1.5
  * Added support for TCP_NODELAY in setsockopt/getsockopt
  * Fixed cmsg space calculation
* Wed Sep  2 2015 asn@cryptomilk.org
- Update to version 1.1.4
  * Fixed handling of msg_name in recvmsg()
  * Fixed sendmsg()/recvmsg() TCP support
  * Fixed several compile warnings
  * Added environment variable to change MTU
* Tue May 12 2015 mpluskal@suse.com
- Rename rpmlintrc so that it complies packaging conventions
* Mon May 11 2015 mpluskal@suse.com
- Mention rpmlintrc as source
* Mon May 11 2015 asn@cryptomilk.org
- Revert library package.
* Mon May 11 2015 asn@cryptomilk.org
- Revert package split
- Require pkg-config and cmake
* Tue May  5 2015 mpluskal@suse.com
- Cleanup spec file
- Use %%cmake install macro
- Split package
- Remove rpmlintrc
* Mon Feb 23 2015 asn@cryptomilk.org
- Update to version 1.1.3
  * Added support for address sanitizer.
  * Fixed leaking of memory and fds of stale sockets.
  * Fixed the library loading code.
* Thu Oct  2 2014 asn@cryptomilk.org
- Update to version 1.1.2
  * Added support for fnctl(F_DUPFD).
  * Added support for glibc 2.20.90.
* Thu Sep 11 2014 asn@cryptomilk.org
- Update to version 1.1.1
  * Disable incomplete address in use check in bind().
  * Added support for IP_PKTINFO in recvmsg().
  * Added support for IPV6_PKTINFO in recvmsg().
  * Added support for IP_RECVDSTADDR in recvmsg() on BSD.
  * Added support for more socket options in getsockopt().
  * Added support for bindresvport().
  * Fixed rebinding on connect().
  * Fixed sockaddr buffer truncation in getsockname() and getpeername().
  * Fixed special cases in bind().
  * Fixed loading libc on some platforms.
  * Fixed memory leaks
  * Fixed calling open from libc.
  * Fixed loading libc functions on some platforms.
* Thu Feb 13 2014 asn@cryptomilk.org
- Initial package.
